-- Create pgstatspack schema tables.	
--
-- By frits.hoogland@interaccess.nl
-- Based on Glenn.Fawcett@Sun.com's snap procedure
--

DROP TABLE if exists pgstatspack_snap;
CREATE TABLE pgstatspack_snap
(
snapid bigint,
ts     timestamp,
description   varchar(255)
);

DROP TABLE if exists pgstatspack_database;
CREATE TABLE pgstatspack_database 
(
  snapid bigint,  
  datid	oid,
  datname varchar(256),
  numbackends int,
  xact_commit bigint,
  xact_rollback bigint,
  blks_read bigint,
  blks_hit bigint
);

DROP TABLE if exists pgstatspack_tables;
CREATE TABLE pgstatspack_tables 
(
  snapid bigint,  
  table_name varchar(256),
  seq_scan bigint,
  seq_tup_read bigint,
  idx_scan bigint,
  idx_tup_fetch bigint,
  n_tup_ins bigint,
  n_tup_upd bigint,
  n_tup_del bigint,
  heap_blks_read bigint,
  heap_blks_hit bigint,
  idx_blks_read bigint,
  idx_blks_hit bigint,
  toast_blks_read bigint,
  toast_blks_hit bigint,
  tidx_blks_read bigint,
  tidx_blks_hit bigint,
  tbl_size bigint,
  idx_size bigint
);

DROP TABLE if exists pgstatspack_indexes;
CREATE TABLE pgstatspack_indexes 
(
  snapid bigint,  
  index_name varchar(256),
  table_name varchar(256),
  idx_scan bigint,
  idx_tup_read bigint,
  idx_tup_fetch bigint,
  idx_blks_read bigint,
  idx_blks_hit bigint
);

DROP TABLE if exists pgstatspack_sequences;
CREATE TABLE pgstatspack_sequences
(
  snapid bigint,
  sequence_schema varchar(256),
  sequence_name varchar(256),
  seq_blks_read bigint,
  seq_blks_hit bigint
);

DROP TABLE if exists pgstatspack_settings;
CREATE TABLE pgstatspack_settings
(
  snapid bigint,
  name text,
  setting text,
  source text
);

CREATE TABLE pgstatspack_statements
(
  snapid bigint NOT NULL,
  userid oid,
  dbid oid,
  query text,
  calls bigint,
  total_time double precision,
  "rows" bigint
);


CREATE TABLE pgstatspack_version
(
  version varchar(10)
);

DROP SEQUENCE if exists pgstatspackid;
CREATE SEQUENCE pgstatspackid;


alter table pgstatspack_database add CONSTRAINT pgstatspack_database_pk primary key (snapid, datid);
alter table pgstatspack_indexes add CONSTRAINT pgstatspack_indexes_pk PRIMARY KEY (snapid, index_name, table_name);
alter table pgstatspack_sequences add CONSTRAINT pgstatspack_sequences_pk PRIMARY KEY (snapid, sequence_schema, sequence_name);
alter table pgstatspack_settings add CONSTRAINT pgstatspack_settings_pk PRIMARY KEY (snapid, name);
alter table pgstatspack_tables add CONSTRAINT pgstatspack_tables_pk PRIMARY KEY (snapid, table_name);
CREATE INDEX idx_pgstatspack_statements_snapid ON pgstatspack_statements USING btree (snapid);

insert into pgstatspack_version values('2.2');
